@@ -21,7 +21,7 @@ def test_format_v2():
 
 
 def run():
-    # test_format_v1()
+    test_format_v1()
     test_format_v2()
 
 
