@@ -2,6 +2,8 @@ import os
 from pyexcel_xlsx import save_data
 from typing import Iterable, Tuple, List
 
+from xlrd import XLRDError
+
 from . import consts
 from . import arg_parse
 from . import exceptions
@@ -12,8 +14,11 @@ from xlsx_parser.xls_parser import XlsParser, XlsParseResult, XlsParserFormat
 
 def get_parsed_rows(xls_dir_path, xls_format: XlsParserFormat, xls_reports_list: List[report.XlsReport]):
     for xls_file in XlsFinder(xls_dir_path).get_files():
-        for row in XlsParser(xls_file, xls_format).parse(xls_reports_list=xls_reports_list):
-            yield row
+        try:
+            for row in XlsParser(xls_file, xls_format).parse(xls_reports_list=xls_reports_list):
+                yield row
+        except XLRDError:
+            print(f"Ошибка парсинга файла {xls_file}")
 
 
 def get_counted_rows(rows: Iterable[XlsParseResult]) -> Iterable[Tuple]:
