@@ -9,7 +9,7 @@ from .xls_formats import XlsParserFormat
 
 
 XlsParseResult = namedtuple(
-    'Point', [
+    'XlsParseResult', [
         'last_name',
         'document_series',
         'document_number',
@@ -114,8 +114,7 @@ class XlsParser:
             book = pyexcel.get_book(file_name=self.xls_path)
         except XLRDError:
             xls_report.error_msg = f"Ошибка парсинга файла {self.xls_path}"
-            print(xls_report.error_msg)
-            return
+            raise
         sheet_numbers = book.number_of_sheets()
         for sheet_number in range(sheet_numbers):
             sheet = book.sheet_by_index(sheet_number)
